import fs from "node:fs";
import path from "node:path";
import { fileURLToPath } from "node:url";

import json from "./data.json" with { type: 'json' };
import { exit } from "node:process";

if(!Array.isArray(json)) {
  console.error('remove `data` part from `{"data": [...]}`')
  exit(1)
}

const __dirname = path.dirname(fileURLToPath(import.meta.url));
const data = [...json]

const idxToRemove = []
const coversToKeep = new Set()
const count = {}

for (let index = 0; index < data.length; index++) {
  const el = data[index];
  const firstChar = el.albumArtist[0]
  count[firstChar] = count[firstChar] ? count[firstChar] + 1 : 1

  if(count[firstChar] > 8) {
    idxToRemove.push(index)
    continue
  }

  coversToKeep.add(el.cover)
}

for (let index = data.length - 1; index >= 0; index--) {
  if(idxToRemove.includes(index)) {
    data.splice(index, 1)
  }  
}

fs.writeFileSync(
  path.join(__dirname, "data.json"),
  JSON.stringify(data, null, 2)
);

const covers = fs.readdirSync(path.join(__dirname, 'covers'));
for (const cover of covers) {
  if(!coversToKeep.has('covers/' + cover)) {
    fs.rmSync(path.join(__dirname, 'covers', cover))
  }
}

for(const cover of coversToKeep) {
  if(!fs.existsSync(path.join(__dirname, cover))) {
    console.log("dbg:", cover, "doesn't exist")
  }
}

console.log("dbg:", "----------")